(define (domain Rover)
(:requirements :typing)
(:types rover waypoint store camera mode lander objective)

(:predicates (at ?x - rover ?y - waypoint) 
             (at_lander ?x - lander ?y - waypoint)
             (can_traverse ?r - rover ?x - waypoint ?y - waypoint)
             (equipped_for_imaging ?r - rover)
	     (equipped_for_soil_analysis ?r - rover)
             (equipped_for_rock_analysis ?r - rover)
             (empty ?s - store)
             (have_rock_analysis ?r - rover); ?w - waypoint)
             (have_soil_analysis ?r - rover); ?w - waypoint)
             (full ?s - store)
	     (calibrated ?c - camera ?r - rover ?w - waypoint ?o - objective) 
	     (supports ?c - camera ?m - mode)
             (available ?r - rover)
             (visible ?w - waypoint ?p - waypoint)
             (have_image ?r - rover ?o - objective ?m - mode)
             (communicated_image_data ?o - objective ?m - mode)
             (communicated_soil_data); ?w - waypoint)
             (communicated_rock_data); ?w - waypoint)
 	     (at_soil_sample ?w - waypoint)
	     (at_rock_sample ?w - waypoint)
   	     (visible_from ?o - objective ?w - waypoint)
	     (store_of ?s - store ?r - rover)
	     (calibration_target ?i - camera ?o - objective)
	     (on_board ?i - camera ?r - rover)
	     (channel_free ?l - lander)

)

	
(:action navigate
:parameters (?x - rover ?y - waypoint ?z - waypoint ?c - camera ?p - objective) 
:precondition (and (can_traverse ?x ?y ?z) (available ?x) (at ?x ?y) 
                (visible ?y ?z)
	    )
:effect (and (not (at ?x ?y)) (at ?x ?z)
;	(when (calibrated ?c ?x ?z ?p) 
(not (calibrated ?c ?x ?z ?p))
;)
		)
	
)


(:action calibrate
 :parameters (?r - rover ?i - camera ?t - objective ?w - waypoint)
 :precondition 
(and 
	(equipped_for_imaging ?r)
	(calibration_target ?i ?t) 
	(at ?r ?w) 
;	(visible_from ?t ?w)
	(on_board ?i ?r))
 :effect ;(when (visible_from ?t ?w) 
(calibrated ?i ?r ?w ?t);)
)


(:action take_image
 :parameters (?r - rover ?p - waypoint ?o - objective ?i - camera ?m - mode)
 :precondition (and (calibrated ?i ?r ?p ?o)
			 (on_board ?i ?r)
                      (equipped_for_imaging ?r)
                      (supports ?i ?m)
;			 (visible_from ?o ?p)
                     (at ?r ?p)
               )
 :effect (and (when (visible_from ?o ?p) (have_image ?r ?o ?m))
              (not (calibrated ?i ?r ?p ?o)) 
         )
;)
		
)



(:action communicate_image_data
 :parameters (?r - rover ?l - lander ?o - objective ?m - mode ?x - waypoint ?y - waypoint)
 :precondition (and (at ?r ?x)
                    (at_lander ?l ?y)
	            (have_image ?r ?o ?m)
                    (visible ?x ?y)
;                    (available ?r)
;                    (channel_free ?l)
               )
 :effect (and 
;(not (available ?r))
;(not (channel_free ?l))(channel_free ?l)
(communicated_image_data ?o ?m)
;(available ?r)
          )
)

(:action sample_soil
:parameters (?x - rover ?s - store ?p - waypoint)
:precondition (and (at ?x ?p) 
                  ; (at_soil_sample ?p) 
                   (equipped_for_soil_analysis ?x) 
                   (store_of ?s ?x) 
                   (empty ?s)
		   (not (full ?s))
		)
:effect (and (when (at_soil_sample ?p) 
                   (and (not (empty ?s)) 
                        (full ?s) 
                        (have_soil_analysis ?x); ?p) 
                        (not (at_soil_sample ?p))
                   )
              ) 
         )
)

(:action sample_rock
:parameters (?x - rover ?s - store ?p - waypoint)
:precondition (and (at ?x ?p) 
             ;      (at_rock_sample ?p) 
                   (equipped_for_rock_analysis ?x) 
                   (store_of ?s ?x)
                   (empty ?s)
		)
:effect (and (when (at_rock_sample ?p)
                   (and	(not (empty ?s)) 
                        (full ?s) 
                        (have_rock_analysis ?x); ?p) 
                        (not (at_rock_sample ?p))
                   )
              )
         )
)

(:action drop
:parameters (?x - rover ?y - store)
:precondition (and 
		(store_of ?y ?x) 
             ;   (full ?y)
	      ;  (not (empty ?y))
	       )
:effect ;(when (and (full ?y) (not (empty ?y)))
              (and (not (full ?y)) 
                   (empty ?y)
	      )
        ; )
)

(:action communicate_soil_data
 :parameters (?r - rover ?l - lander ;?p - waypoint 
              ?x - waypoint ?y - waypoint)
 :precondition (and (at ?r ?x)
                    (at_lander ?l ?y)
                    (have_soil_analysis ?r); ?p) 
                    (visible ?x ?y)
                    (available ?r)
                    (channel_free ?l)
                )
 :effect ;(and (not (available ?r))
         ;     (not (channel_free ?l))
         ;     (channel_free ?l)
	      (communicated_soil_data)
         ;     (available ?r)
	 ; )
)

(:action communicate_rock_data
 :parameters (?r - rover ?l - lander ;?p - waypoint 
		?x - waypoint ?y - waypoint)
 :precondition (and (at ?r ?x)
                    (at_lander ?l ?y)
                    (have_rock_analysis ?r); ?p)
                    (visible ?x ?y)
                    (available ?r)
                    (channel_free ?l)
                )
 :effect ;(and (not (available ?r))
         ;     (not (channel_free ?l))
         ;     (channel_free ?l)
              (communicated_rock_data)
         ;     (available ?r)
         ;)
)
)
(define (problem roverprob1234) (:domain Rover)
(:objects
        general - lander
        colour high_res low_res - mode
        rover0 - rover
        rover0store - store
        waypoint0 waypoint1 waypoint2 waypoint3 waypoint4 waypoint5 - waypoint
        camera0 - camera
        objective1 - objective
        )
(:initstates
(and
	(visible waypoint1 waypoint4) 
	(visible waypoint4 waypoint1)
	(visible waypoint5 waypoint4) 
	(visible waypoint4 waypoint5)
		

	(visible waypoint1 waypoint0) 
	(visible waypoint2 waypoint0)
	(visible waypoint3 waypoint0)
        (visible waypoint0 waypoint1)

        (visible waypoint0 waypoint2)
        (visible waypoint2 waypoint1)
        (visible waypoint1 waypoint2)

        (visible waypoint0 waypoint3)
        (visible waypoint3 waypoint1)
        (visible waypoint1 waypoint3)
        (visible waypoint3 waypoint2)
        (visible waypoint2 waypoint3)



	(not (visible waypoint2 waypoint4))
	(not (visible waypoint4 waypoint2))
	(not (visible waypoint3 waypoint4))
	(not (visible waypoint4 waypoint3))
	(not (visible waypoint0 waypoint4))
	(not (visible waypoint4 waypoint0))
	(not (visible waypoint2 waypoint4))
	(not (visible waypoint4 waypoint2))
	(not (visible waypoint0 waypoint5))
	(not (visible waypoint5 waypoint0))
	(not (visible waypoint1 waypoint5))
	(not (visible waypoint5 waypoint1))
	(not (visible waypoint2 waypoint5))
	(not (visible waypoint5 waypoint2))
	(not (visible waypoint3 waypoint5))
	(not (visible waypoint5 waypoint3))


        (at_lander general waypoint0)
 	(not (at_lander general waypoint1))
 	(not (at_lander general waypoint2))
 	(not (at_lander general waypoint3))
 	(not (at_lander general waypoint4))
 	(not (at_lander general waypoint5))
       (channel_free general)
        (at rover0 waypoint3)
        (available rover0)
       	(not (at rover0 waypoint0))
	(not (at rover0 waypoint1))
	(not (at rover0 waypoint2))
	(not (at rover0 waypoint4))
	(not (at rover0 waypoint5))
       (equipped_for_imaging rover0)
          (can_traverse rover0 waypoint1 waypoint4)
        (can_traverse rover0 waypoint4 waypoint1)
         (can_traverse rover0 waypoint5 waypoint4)
        (can_traverse rover0 waypoint4 waypoint5)
       (can_traverse rover0 waypoint3 waypoint0)
        (can_traverse rover0 waypoint0 waypoint3)
        (can_traverse rover0 waypoint3 waypoint1)
        (can_traverse rover0 waypoint1 waypoint3)
        (can_traverse rover0 waypoint1 waypoint2)
        (can_traverse rover0 waypoint2 waypoint1)
       	(not (can_traverse rover0 waypoint1 waypoint0))
	(not (can_traverse rover0 waypoint0 waypoint1))
	(not (can_traverse rover0 waypoint2 waypoint0))
	(not (can_traverse rover0 waypoint0 waypoint2))
	(not (can_traverse rover0 waypoint2 waypoint3))
	(not (can_traverse rover0 waypoint3 waypoint2))

       	(not (can_traverse rover0 waypoint0 waypoint4))
       	(not (can_traverse rover0 waypoint3 waypoint4))
       	(not (can_traverse rover0 waypoint2 waypoint4))
       	(not (can_traverse rover0 waypoint4 waypoint0))
       	(not (can_traverse rover0 waypoint4 waypoint3))
       	(not (can_traverse rover0 waypoint4 waypoint2))

       	(not (can_traverse rover0 waypoint0 waypoint5))
       	(not (can_traverse rover0 waypoint3 waypoint5))
       	(not (can_traverse rover0 waypoint2 waypoint5))
       	(not (can_traverse rover0 waypoint1 waypoint5))
       	(not (can_traverse rover0 waypoint5 waypoint0))
       	(not (can_traverse rover0 waypoint5 waypoint3))
     	(not (can_traverse rover0 waypoint5 waypoint2))
       	(not (can_traverse rover0 waypoint5 waypoint1))



       (on_board camera0 rover0)
        (calibration_target camera0 objective1)
        (supports camera0 colour)
        (supports camera0 high_res)
                         (not (supports camera0 low_res))
         (store_of rover0store rover0)
          (equipped_for_soil_analysis rover0)
        (equipped_for_rock_analysis rover0)
 	(empty rover0store)
	(not (full rover0store))
	(not (communicated_image_data objective1 high_res))
	(not (communicated_image_data objective1 low_res))
	(not (communicated_image_data objective1 colour))
 	(not (have_image rover0 objective1 colour))
	(not (have_image rover0 objective1 high_res))
	(not (have_image rover0 objective1 low_res))
	(not (have_soil_analysis rover0))
	(not (have_rock_analysis rover0))
	(not (communicated_soil_data))
	(not (communicated_rock_data))
	(not (calibrated camera0 rover0 waypoint0 objective1))
 	 (not (calibrated camera0 rover0 waypoint1 objective1))
	(not (calibrated camera0 rover0 waypoint2 objective1))
 	 (not (calibrated camera0 rover0 waypoint3 objective1))
	(not (calibrated camera0 rover0 waypoint4 objective1))
 	 (not (calibrated camera0 rover0 waypoint5 objective1))

         (not (visible_from objective1 waypoint1))
         (not (visible_from objective1 waypoint2))
         (not (visible_from objective1 waypoint3))

	(not (at_soil_sample waypoint0))
	(not (at_soil_sample waypoint1))
	(not (at_soil_sample waypoint2))
	(not (at_soil_sample waypoint3))

	(not (at_rock_sample waypoint0))
	(not (at_rock_sample waypoint1))
	(not (at_rock_sample waypoint3))
	(not (at_rock_sample waypoint2))

	(or
         (visible_from objective1 waypoint0)
         (visible_from objective1 waypoint4)
         (visible_from objective1 waypoint5)
	)
	(or (not (visible_from objective1 waypoint0)) (not (visible_from objective1 waypoint4)))
	(or (not (visible_from objective1 waypoint0)) (not (visible_from objective1 waypoint5)))
	(or (not (visible_from objective1 waypoint4)) (not (visible_from objective1 waypoint5)))


	(or
	 (at_soil_sample waypoint4)
	 (at_soil_sample waypoint5)
	)
	(or (not (at_soil_sample waypoint4)) (not (at_soil_sample waypoint5)))

	(or
          (at_rock_sample waypoint4)
    	  (at_rock_sample waypoint5)
 	)
	(or (not(at_rock_sample waypoint4) ) (not (at_rock_sample waypoint5)))

)
)

(:goal (and (communicated_image_data objective1 high_res)
          (communicated_soil_data)
            (communicated_rock_data)
       )
)
)

