
(define (domain logistics)
  (:requirements :strips :typing :adl )			
  (:types OBJ TRUCK LOCATION AIRPLANE CITY AIRPORT )
  (:predicates 	(at_tl ?obj - TRUCK  ?loc - LOCATION)
		(at_ta ?obj - TRUCK  ?loc - AIRPORT)
		(at_aa ?obj - AIRPLANE ?loc - AIRPORT)
		(at_ol ?obj - OBJ ?loc - LOCATION)
		(at_oa ?obj - OBJ ?loc - AIRPORT)
		(in_ot ?obj1 - OBJ ?obj2 - TRUCK)
		(in_oa ?obj1 - OBJ ?obj2 - AIRPLANE)
		(in_city_l ?loc - LOCATION ?city - CITY)
		(in_city_a ?loc - AIRPORT ?city - CITY)
		(in_city_t ?loc - TRUCK ?city - CITY))
(:action sense_package_loc_t
 :parameters (?obj - OBJ ?loc - LOCATION ?truck - TRUCK)
:precondition (at_tl ?truck ?loc)
 :observables (at_ol ?obj ?loc))


(:action sense_package_ap_t
 :parameters (?obj - OBJ ?loc - AIRPORT ?truck - TRUCK)
 :precondition (at_ta ?truck ?loc)
 :observables (at_oa ?obj ?loc))
	     
(:action sense_package_ap_a
 :parameters (?obj - OBJ ?loc - AIRPORT ?airplane - AIRPLANE)
 :precondition (at_aa ?airplane ?loc)
 :observables (at_oa ?obj ?loc))

(:action LOAD_TRUCK_LOC
  :parameters
   (?obj - OBJ
    ?truck - TRUCK
    ?loc - LOCATION 
    ?city - CITY)
    :precondition
   (and 
	(at_tl ?truck ?loc) 
 	(in_city_t ?truck ?city)
	(in_city_l ?loc ?city)
  
   )
  :effect
   (when (at_ol ?obj ?loc) 
         (and (not (at_ol ?obj ?loc)) 
	  (in_ot ?obj ?truck))))

(:action LOAD_TRUCK_AP
  :parameters
   (?obj - OBJ
    ?truck - TRUCK
    ?loc - AIRPORT
    ?city - CITY)
  :precondition
   (and 
	(at_ta ?truck ?loc) 
 	(in_city_t ?truck ?city)
	(in_city_a ?loc ?city)
  
   )
  :effect
   (when (at_oa ?obj ?loc) 
         (and (not (at_oa ?obj ?loc)) 
	  (in_ot ?obj ?truck))))

(:action LOAD_AIRPLANE
  :parameters
   (?obj - OBJ ?airplane - AIRPLANE ?loc - AIRPORT) 
  :precondition
   (at_aa ?airplane ?loc)
  :effect
   (when (at_oa ?obj ?loc) 
         (and (not (at_oa ?obj ?loc)) 
              (in_oa ?obj ?airplane))))

(:action UNLOAD_TRUCK_LOC
  :parameters
   (?obj - OBJ
    ?truck - TRUCK
    ?loc - LOCATION
    ?city - CITY)
  :precondition
   (and 
	(at_tl ?truck ?loc) 
	(in_city_t ?truck ?city)
	(in_city_l ?loc ?city)
        ;(not (at_ol ?obj ?loc))
   )
  :effect
   (when (in_ot ?obj ?truck) 
	 (and (not (in_ot ?obj ?truck)) 
              (at_ol ?obj ?loc))))

(:action UNLOAD_TRUCK_AP
  :parameters
   (?obj - OBJ
    ?truck - TRUCK
    ?loc - AIRPORT
    ?city - CITY)
  :precondition
   (and 
	(at_ta ?truck ?loc) 
	(in_city_t ?truck ?city)
	(in_city_a ?loc ?city)
        ;(not (at_ol ?obj ?loc))
   )
  :effect
   (when (in_ot ?obj ?truck) 
	 (and (not (in_ot ?obj ?truck)) 
              (at_oa ?obj ?loc))))

(:action UNLOAD_AIRPLANE
  :parameters
   (?obj - OBJ
    ?airplane - AIRPLANE
    ?loc - AIRPORT)
  :precondition
   (at_aa ?airplane ?loc)	
  :effect
   (when (in_oa ?obj ?airplane)   
	 (and (not (in_oa ?obj ?airplane)) 
              (at_oa ?obj ?loc))))

(:action DRIVE_TRUCK_LOC_AP
  :parameters
   (?truck - TRUCK
    ?loc1 - LOCATION
    ?loc2 - AIRPORT
    ?city - CITY)
  :precondition
   (and (at_tl ?truck ?loc1)
        (in_city_l ?loc1 ?city)
        (in_city_a ?loc2 ?city)
	(in_city_t ?truck ?city)
	;(not (at_ta ?truck ?loc2))
   )
  :effect
   (and (not (at_tl ?truck ?loc1)) 
        (at_ta ?truck ?loc2)))

(:action DRIVE_TRUCK_AP_LOC
  :parameters
   (?truck - TRUCK
    ?loc1 - AIRPORT
    ?loc2 - LOCATION 
    ?city - CITY)
    :precondition
   (and (at_ta ?truck ?loc1)
        (in_city_a ?loc1 ?city)
        (in_city_l ?loc2 ?city)
	(in_city_t ?truck ?city)
	;(not (at_tl ?truck ?loc2))
   )
  :effect
   (and (not (at_ta ?truck ?loc1)) 
        (at_tl ?truck ?loc2)))

(:action FLY_AIRPLANE
  :parameters
   (?airplane - AIRPLANE
    ?loc1 - AIRPORT
    ?loc2 - AIRPORT)
 
  :precondition
  (and  
	(at_aa ?airplane ?loc1)
	;(not (at ?airplane ?loc2) 
  )
  :effect
   (and (not (at_aa ?airplane ?loc1) )
        (at_aa ?airplane ?loc2 )))




)

 
;;; a three step plan works
(define (problem att_log0) 
  (:domain logistics_conf)
;;  (:requirements :strips :equality :typing :conditional-effects :disjunctive-preconditions)			
  (:objects 	package1 - OBJ
		package2 - OBJ
		pgh_truck - TRUCK
		bos_truck - TRUCK
	;	phx_truck - TRUCK
		airplane1 - AIRPLANE
		bos_po - LOCATION
		pgh_po - LOCATION
	;	phx_po - LOCATION
		bos_airport - AIRPORT 
		pgh_airport - AIRPORT 
	;	phx_airport - AIRPORT
		pgh - CITY
		bos - CITY
 	;	phx - CITY
	)
 (:initstates (and
	(or
	  (at_ol package1 pgh_po)
 	  (at_ol package1 bos_po)
	 )
	(or
	 (at_ol package2 pgh_po)
	 (at_ol package2 bos_po)
	)
	(or
	  (not (at_ol package1 pgh_po))
 	  (not (at_ol package1 bos_po))
	 )
	(or
	 (not (at_ol package2 pgh_po))
	 (not (at_ol package2 bos_po))
	)
	(not (in_oa package1 airplane1))
        (not (in_ot package1 bos_truck))
        (not (in_ot package1 pgh_truck))
	(not (in_oa package2 airplane1))
        (not (in_ot package2 bos_truck))
        (not (in_ot package2 pgh_truck))
	(not (at_oa package1 pgh_airport))	
	(not (at_oa package1 bos_airport))
	(not (at_oa package2 pgh_airport))	
	(not (at_oa package2 bos_airport))

	 (at_aa airplane1 pgh_airport)
	(not (at_aa airplane1 bos_airport))
	 (at_tl bos_truck bos_po)
        (not (at_ta bos_truck bos_airport))
	(not (at_tl bos_truck pgh_po))
	(not (at_ta bos_truck pgh_airport))
	 (at_tl pgh_truck pgh_po)
       (not (at_ta pgh_truck bos_airport))
        (not (at_tl pgh_truck bos_po))
        (not (at_ta pgh_truck pgh_airport))
;	 (at_tl phx_truck phx_po)
	 (in_city_l bos_po bos)
	(not (in_city_l bos_po pgh))
	 (in_city_a bos_airport bos)
	(not (in_city_a bos_airport pgh))
;	 (in_city_l phx_po phx)
;	 (in_city_a phx_airport phx)
	 (in_city_l pgh_po pgh)
	(not (in_city_l pgh_po bos))
	 (in_city_a pgh_airport pgh)
	(not (in_city_a pgh_airport bos))
	 (in_city_t pgh_truck pgh)
	(not (in_city_t pgh_truck bos))
	 (in_city_t bos_truck bos)
	(not (in_city_t bos_truck pgh))
;	 (in_city_T phx_truck phx)
))
  (:goal;conformantgoal
	 (and 
	(at_oa package1 bos_airport)
	(at_oa package2 bos_airport)
	)	
  )
)
