(define (domain rover)
  (:model (:dynamics :non-deterministic) (:feedback :null))
(:types ROVER WAY STORE CAMERA MODE LANDER OBJ DUMMY)
(:predicates (at ROVER WAY) 
             (at_lander LANDER WAY)
             (can_traverse ROVER WAY WAY)
             (imaging ROVER)
              (empty STORE)
           (have_rock ROVER)
           (have_soil ROVER)
              (full STORE)
	     (calibrated CAMERA ROVER WAY OBJ) 
	     (supports CAMERA MODE)
             (available ROVER)
             (visible WAY WAY)
             (have_image ROVER OBJ MODE)
             (comm_soil DUMMY)
            (comm_rock DUMMY)
             (comm_img OBJ MODE)
;;	     (at_soil_sample WAY)
;;	     (at_rock_sample WAY)
;;             (visible_from OBJ WAY)
 	     (store_of STORE ROVER)
	     (calibration_target CAMERA OBJ)
	     (on_board CAMERA ROVER)
	     (channel_free LANDER)
)
(:functions (visible_from OBJ WAY)
            (at_soil_sample DUMMY WAY)
            (at_rock_sample DUMMY WAY)
)
	
(:action navigate
:parameters ?x - ROVER ?y - WAY ?z - WAY ?c - CAMERA ?p - OBJ
 :precondition 
  (:and (can_traverse ?x ?y ?z) 
	(available ?x) 
	(at ?x ?y) 
        (visible ?y ?z)
   )
:effect (:set (at ?x ?y) false)
	(:set (at ?x ?z) true)
	(:when (calibrated ?c ?x ?z ?p) (:set (calibrated ?c ?x ?z ?p) false)))

(:action sample_soil
 :parameters ?x - ROVER ?s - STORE ?p - WAY ?d - DUMMY
 :precondition 
  (:and (at ?x ?p) 
	(store_of ?s ?x)
	(empty ?s)
  )
:effect 
;;(:when (= (at_soil_sample ?d) ?p) (:set (:not (= (at_soil_sample ?d) ?p))))
(:when (= (at_soil_sample ?d) ?p) (:set (empty ?s) false))
(:when (= (at_soil_sample ?d) ?p) (:set (full ?s) true))
(:when (= (at_soil_sample ?d) ?p) (:set (have_soil ?x) true))
	
)

(:action sample_rock
:parameters ?x - ROVER ?s - STORE ?p - WAY ?d - DUMMY
 :precondition 
  (:and (at ?x ?p) 
	(store_of ?s ?x)   
	(empty ?s)
  )
:effect 
;;(:when (= (at_rock_sample ?d) ?p) (:set (at_rock_sample ?d) ?p))
 (:when (= (at_rock_sample ?d) ?p) (:set (empty ?s) false))
 (:when (= (at_rock_sample ?d) ?p) (:set (full ?s) true))
 (:when (= (at_rock_sample ?d) ?p) (:set (have_rock ?x) true))
	
)


(:action drop
 :parameters ?x - ROVER ?y - STORE
 :precondition 
  (:and (store_of ?y ?x) 
;;	(full ?y)
  )
 :effect (:when (full ?y) (:set (empty ?y) true))
         (:when (full ?y) (:set (full ?y) false)))

(:action calibrate
 :parameters ?r - ROVER ?i - CAMERA ?t - OBJ ?w - WAY
 :precondition 
  (:and (imaging ?r)
	(calibration_target ?i ?t) 
	(at ?r ?w) 
	(on_board ?i ?r))
 :effect  (:set (calibrated ?i ?r ?w ?t) true)
)


(:action take_image
 :parameters ?r - ROVER ?p - WAY ?o - OBJ ?i - CAMERA ?m - MODE
 :precondition (:and  (calibrated ?i ?r ?p ?o)
			(on_board ?i ?r)
                      (imaging ?r)
                      (supports ?i ?m)
                     (at ?r ?p)
               )
 :effect (:when (= (visible_from ?o) ?p) 
                (:set (have_image ?r ?o ?m) true))
         (:set (calibrated ?i ?r ?p ?o) false))


(:action communicate_soil_data
:parameters ?r - ROVER ?l - LANDER ?p - WAY ?x - WAY ?y - WAY ?d - DUMMY
 :precondition (:and (at ?r ?x)
		     (at_lander ?l ?y)
                   (have_soil ?r) 
                     (visible ?x ?y)
 	
             	)
  :effect 
 	 (:set (comm_soil ?d) true) )

(:action communicate_rock_data
 :parameters ?r - ROVER ?l - LANDER ?p - WAY ?x - WAY ?y - WAY ?d - DUMMY
 :precondition 
  (:and (at ?r ?x)
	(at_lander ?l ?y)
	(have_rock ?r)
        (visible ?x ?y)
  )
 :effect (:set (comm_rock ?d) true))


(:action communicate_image_data
 :parameters ?r - ROVER ?l - LANDER ?o - OBJ ?m - MODE ?x - WAY ?y - WAY
 :precondition 
  (:and (at ?r ?x)
	(at_lander ?l ?y)
	(have_image ?r ?o ?m)
	(visible ?x ?y)
   )
 :effect (:set (comm_img ?o ?m) true))
)

(define (problem p1) 
(:domain rover)
(:objects
        general - LANDER
        colour high_res low_res - MODE
        rover0 - ROVER
         rover0store - STORE
        way0 way1 way2 way3 - WAY
        camera0 - CAMERA
        obj1 - OBJ
	d - DUMMY
        )
(:init

	(:set (store_of rover0store rover0) true)
	 (:set (visible way1 way0) true)
	 (:set (visible way2 way0) true)
	 (:set (visible way3 way0) true)
        (:set (visible way0 way1) true)
        (:set (visible way0 way2) true)
        (:set (visible way2 way1) true)
        (:set (visible way1 way2) true)
        (:set (visible way0 way3) true)
        (:set (visible way3 way1) true)
        (:set (visible way1 way3) true)
        (:set (visible way3 way2) true)
        (:set (visible way2 way3) true)
	 (:set (imaging rover0) true)
;;;        (:set (at_soil_sample d way0) false)
;;;	(:set (at_rock_sample way0) false)
;;        (:set (at_soil_sample way1) false)
;;        (:set (at_rock_sample way1) false)
;;        (:set (at_soil_sample way2) false)
;;        (:set (at_rock_sample way2) false)
;;         (:set (at_soil_sample way3) false)
;;         (:set (at_rock_sample way3) false)
        (:set (at_lander general way0) true)
        (:set (at_lander general way1) false)
        (:set (at_lander general way2) false)
        (:set (at_lander general way3) false)
        (:set (channel_free general) true)
        (:set (at rover0 way3) true)
        (:set (at rover0 way0) false)
        (:set (at rover0 way1) false)
        (:set (at rover0 way2) false)
        (:set (available rover0) true)
         (:set (empty rover0store) true)
	(:set (full rover0store) false)
        (:set (can_traverse rover0 way3 way0) true)
        (:set (can_traverse rover0 way0 way3) true)
        (:set (can_traverse rover0 way3 way1) true)
        (:set (can_traverse rover0 way1 way3) true)
        (:set (can_traverse rover0 way1 way2) true)
        (:set (can_traverse rover0 way2 way1) true)
        (:set (can_traverse rover0 way1 way0) false)
        (:set (can_traverse rover0 way0 way1) false)
        (:set (can_traverse rover0 way2 way0) false)
        (:set (can_traverse rover0 way0 way2) false)
        (:set (can_traverse rover0 way2 way3) false)
        (:set (can_traverse rover0 way3 way2) false)
	(:set (have_image rover0 obj1 colour) false)
	(:set (have_image rover0 obj1 high_res) false)
	(:set (have_image rover0 obj1 low_res) false)
        (:set (on_board camera0 rover0) true)
        (:set (calibration_target camera0 obj1) true)
        (:set (supports camera0 colour) true)
        (:set (supports camera0 low_res) false)
        (:set (supports camera0 high_res) true)
;;	(:set (visible_from obj1 way1) false)
;;        (:set (visible_from obj1 way0) false)
        (:set (visible_from obj1) way2)
 ;;       (:set (visible_from obj1 way3) false)
	(:set (comm_img obj1 colour) false)
	(:set (comm_img obj1 low_res) false)
	(:set (comm_img obj1 high_res) false)
        (:set (have_image rover0 obj1 colour) false)
        (:set (have_image rover0 obj1 low_res) false)
        (:set (have_image rover0 obj1 high_res) false)
	(:set (comm_soil d) false)
	(:set (comm_rock d) false)
	(:set (have_rock rover0) false)
	(:set (have_soil rover0) false)

	(:set (calibrated camera0 rover0 way0 obj1) false) 
	(:set (calibrated camera0 rover0 way1 obj1) false) 
	(:set (calibrated camera0 rover0 way2 obj1) false) 
	(:set (calibrated camera0 rover0 way3 obj1) false) )

(:goal  (comm_img obj1 high_res)

))

(define (problem p2) 
(:domain rover)
(:objects
        general - LANDER
        colour high_res low_res - MODE
        rover0 - ROVER
         rover0store - STORE
        way0 way1 way2 way3 - WAY
        camera0 - CAMERA
        obj1  - OBJ
	d - DUMMY
        )
(:init
	(:set (store_of rover0store rover0) true)
	 (:set (visible way1 way0) true)
	 (:set (visible way2 way0) true)
	 (:set (visible way3 way0) true)
        (:set (visible way0 way1) true)
        (:set (visible way0 way2) true)
        (:set (visible way2 way1) true)
        (:set (visible way1 way2) true)
        (:set (visible way0 way3) true)
        (:set (visible way3 way1) true)
        (:set (visible way1 way3) true)
        (:set (visible way3 way2) true)
        (:set (visible way2 way3) true)
	 (:set (imaging rover0) true)
;;        (:set (at_soil_sample way0) false)
;;	(:set (at_rock_sample way0) false)
 ;;       (:set (at_soil_sample way1) false)
  ;;      (:set (at_rock_sample way1) false)
   ;;     (:set (at_soil_sample way2) false)
    ;;    (:set (at_rock_sample way2) false)
    ;;     (:set (at_soil_sample way3) false)
     ;;    (:set (at_rock_sample way3) false)
        (:set (at_lander general way0) true)
        (:set (at_lander general way1) false)
        (:set (at_lander general way2) false)
        (:set (at_lander general way3) false)
        (:set (channel_free general) true)
        (:set (at rover0 way3) true)
        (:set (at rover0 way0) false)
        (:set (at rover0 way1) false)
        (:set (at rover0 way2) false)
        (:set (available rover0) true)
         (:set (empty rover0store) true)
	(:set (full rover0store) false)
        (:set (can_traverse rover0 way3 way0) true)
        (:set (can_traverse rover0 way0 way3) true)
        (:set (can_traverse rover0 way3 way1) true)
        (:set (can_traverse rover0 way1 way3) true)
        (:set (can_traverse rover0 way1 way2) true)
        (:set (can_traverse rover0 way2 way1) true)
        (:set (can_traverse rover0 way1 way0) false)
        (:set (can_traverse rover0 way0 way1) false)
        (:set (can_traverse rover0 way2 way0) false)
        (:set (can_traverse rover0 way0 way2) false)
        (:set (can_traverse rover0 way2 way3) false)
        (:set (can_traverse rover0 way3 way2) false)
	(:set (have_image rover0 obj1 colour) false)
	(:set (have_image rover0 obj1 high_res) false)
	(:set (have_image rover0 obj1 low_res) false)
        (:set (on_board camera0 rover0) true)
        (:set (calibration_target camera0 obj1) true)
        (:set (supports camera0 colour) true)
        (:set (supports camera0 low_res) false)
        (:set (supports camera0 high_res) true)

	(:set (visible_from obj1) :in {way0 way1})

	(:set (comm_img obj1 colour) false)
	(:set (comm_img obj1 low_res) false)
	(:set (comm_img obj1 high_res) false)
        (:set (have_image rover0 obj1 colour) false)
        (:set (have_image rover0 obj1 low_res) false)
        (:set (have_image rover0 obj1 high_res) false)
	(:set (comm_soil d) false)
	(:set (comm_rock d) false)
	(:set (have_rock rover0) false)
	(:set (have_soil rover0) false)

	(:set (calibrated camera0 rover0 way0 obj1) false) 
	(:set (calibrated camera0 rover0 way1 obj1) false) 
	(:set (calibrated camera0 rover0 way2 obj1) false) 
	(:set (calibrated camera0 rover0 way3 obj1) false) )


(:goal  (comm_img obj1 high_res)
 ;;(have_image rover0 obj1 high_res) 
 ;;(at rover0 way1) 
)
)

(define (problem p3) 
(:domain rover)
(:objects
        general - LANDER
        colour high_res low_res - MODE
        rover0 - ROVER
         rover0store - STORE
        way0 way1 way2 way3 - WAY
        camera0 - CAMERA
        obj1  - OBJ
	d - DUMMY
        )
(:init
	(:set (store_of rover0store rover0) true)
	 (:set (visible way1 way0) true)
	 (:set (visible way2 way0) true)
	 (:set (visible way3 way0) true)
        (:set (visible way0 way1) true)
        (:set (visible way0 way2) true)
        (:set (visible way2 way1) true)
        (:set (visible way1 way2) true)
        (:set (visible way0 way3) true)
        (:set (visible way3 way1) true)
        (:set (visible way1 way3) true)
        (:set (visible way3 way2) true)
        (:set (visible way2 way3) true)
	 (:set (imaging rover0) true)
;;        (:set (at_soil_sample way0) false)
;;	(:set (at_rock_sample way0) false)
;;        (:set (at_soil_sample way1) false)
;;        (:set (at_rock_sample way1) false)
;;        (:set (at_soil_sample way2) false)
;;        (:set (at_rock_sample way2) false)
;;         (:set (at_soil_sample way3) false)
;;         (:set (at_rock_sample way3) false)
        (:set (at_lander general way0) true)
        (:set (at_lander general way1) false)
        (:set (at_lander general way2) false)
        (:set (at_lander general way3) false)
        (:set (channel_free general) true)
        (:set (at rover0 way3) true)
        (:set (at rover0 way0) false)
        (:set (at rover0 way1) false)
        (:set (at rover0 way2) false)
        (:set (available rover0) true)
         (:set (empty rover0store) true)
	(:set (full rover0store) false)
        (:set (can_traverse rover0 way3 way0) true)
        (:set (can_traverse rover0 way0 way3) true)
        (:set (can_traverse rover0 way3 way1) true)
        (:set (can_traverse rover0 way1 way3) true)
        (:set (can_traverse rover0 way1 way2) true)
        (:set (can_traverse rover0 way2 way1) true)
        (:set (can_traverse rover0 way1 way0) false)
        (:set (can_traverse rover0 way0 way1) false)
        (:set (can_traverse rover0 way2 way0) false)
        (:set (can_traverse rover0 way0 way2) false)
        (:set (can_traverse rover0 way2 way3) false)
        (:set (can_traverse rover0 way3 way2) false)
	(:set (have_image rover0 obj1 colour) false)
	(:set (have_image rover0 obj1 high_res) false)
	(:set (have_image rover0 obj1 low_res) false)
        (:set (on_board camera0 rover0) true)
        (:set (calibration_target camera0 obj1) true)
        (:set (supports camera0 colour) true)
        (:set (supports camera0 low_res) false)
        (:set (supports camera0 high_res) true)

	(:set (visible_from obj1) :in {way0 way1 way3})

	(:set (have_rock rover0) false)
	(:set (have_soil rover0) false)

	(:set (comm_img obj1 colour) false)
	(:set (comm_img obj1 low_res) false)
	(:set (comm_img obj1 high_res) false)
        (:set (have_image rover0 obj1 colour) false)
        (:set (have_image rover0 obj1 low_res) false)
        (:set (have_image rover0 obj1 high_res) false)
	(:set (comm_soil d) false)
	(:set (comm_rock d) false)
	(:set (calibrated camera0 rover0 way0 obj1) false) 
	(:set (calibrated camera0 rover0 way1 obj1) false) 
	(:set (calibrated camera0 rover0 way2 obj1) false) 
	(:set (calibrated camera0 rover0 way3 obj1) false) )


(:goal  (comm_img obj1 high_res)
 ;;(have_image rover0 obj1 high_res) 
 ;;(at rover0 way1) 
)
)
(define (problem p4) 
(:domain rover)
(:objects
        general - LANDER
        colour high_res low_res - MODE
        rover0 - ROVER
         rover0store - STORE
        way0 way1 way2 way3 - WAY
        camera0 - CAMERA
        obj1  - OBJ
	d - DUMMY
        )
(:init
	(:set (store_of rover0store rover0) true)
	 (:set (visible way1 way0) true)
	 (:set (visible way2 way0) true)
	 (:set (visible way3 way0) true)
        (:set (visible way0 way1) true)
        (:set (visible way0 way2) true)
        (:set (visible way2 way1) true)
        (:set (visible way1 way2) true)
        (:set (visible way0 way3) true)
        (:set (visible way3 way1) true)
        (:set (visible way1 way3) true)
        (:set (visible way3 way2) true)
        (:set (visible way2 way3) true)
	 (:set (imaging rover0) true)
;;        (:set (at_soil_sample way0) false)
;;	(:set (at_rock_sample way0) false)
;;        (:set (at_soil_sample way1) false)
;;        (:set (at_rock_sample way1) false)
;;        (:set (at_soil_sample way2) false)
;;        (:set (at_rock_sample way2) false)
;;         (:set (at_soil_sample way3) false)
;;         (:set (at_rock_sample way3) false)
        (:set (at_lander general way0) true)
        (:set (at_lander general way1) false)
        (:set (at_lander general way2) false)
        (:set (at_lander general way3) false)
        (:set (channel_free general) true)
        (:set (at rover0 way3) true)
        (:set (at rover0 way0) false)
        (:set (at rover0 way1) false)
        (:set (at rover0 way2) false)
        (:set (available rover0) true)
         (:set (empty rover0store) true)
	(:set (full rover0store) false)
        (:set (can_traverse rover0 way3 way0) true)
        (:set (can_traverse rover0 way0 way3) true)
        (:set (can_traverse rover0 way3 way1) true)
        (:set (can_traverse rover0 way1 way3) true)
        (:set (can_traverse rover0 way1 way2) true)
        (:set (can_traverse rover0 way2 way1) true)
        (:set (can_traverse rover0 way1 way0) false)
        (:set (can_traverse rover0 way0 way1) false)
        (:set (can_traverse rover0 way2 way0) false)
        (:set (can_traverse rover0 way0 way2) false)
        (:set (can_traverse rover0 way2 way3) false)
        (:set (can_traverse rover0 way3 way2) false)
	(:set (have_image rover0 obj1 colour) false)
	(:set (have_image rover0 obj1 high_res) false)
	(:set (have_image rover0 obj1 low_res) false)
        (:set (on_board camera0 rover0) true)
        (:set (calibration_target camera0 obj1) true)
        (:set (supports camera0 colour) true)
        (:set (supports camera0 low_res) false)
        (:set (supports camera0 high_res) true)

	(:set (visible_from obj1) :in {way0 way1 way2 way3})
	(:set (have_rock rover0) false)
	(:set (have_soil rover0) false)


	(:set (comm_img obj1 colour) false)
	(:set (comm_img obj1 low_res) false)
	(:set (comm_img obj1 high_res) false)
        (:set (have_image rover0 obj1 colour) false)
        (:set (have_image rover0 obj1 low_res) false)
        (:set (have_image rover0 obj1 high_res) false)
	(:set (comm_soil d) false)
	(:set (comm_rock d) false)
	(:set (calibrated camera0 rover0 way0 obj1) false) 
	(:set (calibrated camera0 rover0 way1 obj1) false) 
	(:set (calibrated camera0 rover0 way2 obj1) false) 
	(:set (calibrated camera0 rover0 way3 obj1) false) )


(:goal  (comm_img obj1 high_res)
 ;;(have_image rover0 obj1 high_res) 
 ;;(at rover0 way1) 
)
)

(define (problem p5) 
(:domain rover)
(:objects
        general - LANDER
        colour high_res low_res - MODE
        rover0 - ROVER
         rover0store - STORE
        way0 way1 way2 way3 - WAY
        camera0 - CAMERA
        obj1  - OBJ
	d - DUMMY

        )
(:init
	(:set (store_of rover0store rover0) true)
	 (:set (visible way1 way0) true)
	 (:set (visible way2 way0) true)
	 (:set (visible way3 way0) true)
        (:set (visible way0 way1) true)
        (:set (visible way0 way2) true)
        (:set (visible way2 way1) true)
        (:set (visible way1 way2) true)
        (:set (visible way0 way3) true)
        (:set (visible way3 way1) true)
        (:set (visible way1 way3) true)
        (:set (visible way3 way2) true)
        (:set (visible way2 way3) true)
	 (:set (imaging rover0) true)

;;        (:set (at_soil_sample way0) false)
;;	(:set (at_rock_sample way0) false)
;;        (:set (at_soil_sample way1) false)
;;        (:set (at_rock_sample way1) false)
;;        (:set (at_soil_sample way2) false)
;;        (:set (at_rock_sample way2) false)
;;         (:set (at_soil_sample way3) false)
;;         (:set (at_rock_sample way3) false)

;;	(:set (at_soil_sample d) way3)

	(:set (at_rock_sample d) :in {way2 way3})
	(:set (at_soil_sample d) :in {way0 way1})

        (:set (at_lander general way0) true)
        (:set (at_lander general way1) false)
        (:set (at_lander general way2) false)
        (:set (at_lander general way3) false)
        (:set (channel_free general) true)
        (:set (at rover0 way3) true)
        (:set (at rover0 way0) false)
        (:set (at rover0 way1) false)
        (:set (at rover0 way2) false)
        (:set (available rover0) true)
        (:set (empty rover0store)  true)
	(:set (full rover0store) false)
        (:set (can_traverse rover0 way3 way0) true)
        (:set (can_traverse rover0 way0 way3) true)
        (:set (can_traverse rover0 way3 way1) true)
        (:set (can_traverse rover0 way1 way3) true)
        (:set (can_traverse rover0 way1 way2) true)
        (:set (can_traverse rover0 way2 way1) true)
        (:set (can_traverse rover0 way1 way0) false)
        (:set (can_traverse rover0 way0 way1) false)
        (:set (can_traverse rover0 way2 way0) false)
        (:set (can_traverse rover0 way0 way2) false)
        (:set (can_traverse rover0 way2 way3) false)
        (:set (can_traverse rover0 way3 way2) false)
	(:set (have_image rover0 obj1 colour) false)
	(:set (have_image rover0 obj1 high_res) false)
	(:set (have_image rover0 obj1 low_res) false)
        (:set (on_board camera0 rover0) true)
        (:set (calibration_target camera0 obj1) true)
        (:set (supports camera0 colour) true)
        (:set (supports camera0 low_res) false)
        (:set (supports camera0 high_res) true)

	(:set (visible_from obj1) :in {way0 way1 way3})
;;	(:set (visible_from obj1) :in {way0})
	
	(:set (have_rock rover0) false)
	(:set (have_soil rover0) false)

	(:set (comm_img obj1 colour) false)
	(:set (comm_img obj1 low_res) false)
	(:set (comm_img obj1 high_res) false)
        (:set (have_image rover0 obj1 colour) false)
        (:set (have_image rover0 obj1 low_res) false)
        (:set (have_image rover0 obj1 high_res) false)
	(:set (comm_soil d) false)
	(:set (comm_rock d) false)



(:set (calibrated camera0 rover0 way0 obj1) false) 
	(:set (calibrated camera0 rover0 way1 obj1) false) 
	(:set (calibrated camera0 rover0 way2 obj1) false) 
	(:set (calibrated camera0 rover0 way3 obj1) false) )


(:goal (:and (comm_img obj1 high_res)
	(comm_soil d)
	(comm_rock d)
)))

(define (problem p6) 
(:domain rover)
(:objects
        general - LANDER
        colour high_res low_res - MODE
        rover0 - ROVER
         rover0store - STORE
        way0 way1 way2 way3 way4 way5 - WAY
        camera0 - CAMERA
        obj1  - OBJ
	d - DUMMY

        )
(:init
	(:set (store_of rover0store rover0) true)
	(:set (visible way1 way4) true)
	(:set (visible way4 way1) true)
	(:set (visible way5 way4) true)
	(:set (visible way4 way5) true)

	 (:set (visible way1 way0) true)
	 (:set (visible way2 way0) true)
	 (:set (visible way3 way0) true)
        (:set (visible way0 way1) true)
        (:set (visible way0 way2) true)
        (:set (visible way2 way1) true)
        (:set (visible way1 way2) true)
        (:set (visible way0 way3) true)
        (:set (visible way3 way1) true)
        (:set (visible way1 way3) true)
        (:set (visible way3 way2) true)
        (:set (visible way2 way3) true)
	 (:set (imaging rover0) true)



	(:set (at_rock_sample d) :in {way4 way5})
	(:set (at_soil_sample d) :in {way4 way5})

        (:set (at_lander general way0) true)
        (:set (at_lander general way1) false)
        (:set (at_lander general way2) false)
        (:set (at_lander general way3) false)
    	(:set (at_lander general way4) false)
 	(:set (at_lander general way5) false)
 
    (:set (channel_free general) true)
        (:set (at rover0 way3) true)
        (:set (at rover0 way0) false)
        (:set (at rover0 way1) false)
        (:set (at rover0 way2) false)

     	(:set (at rover0 way4) false)
	(:set (at rover0 way5) false)

   (:set (available rover0) true)
        (:set (empty rover0store)  true)
	(:set (full rover0store) false)
        (:set (can_traverse rover0 way1 way4) true)
        (:set (can_traverse rover0 way4 way1) true)
        (:set (can_traverse rover0 way5 way4) true)
        (:set (can_traverse rover0 way4 way5) true)
       	(:set (can_traverse rover0 way0 way4) false)
       	(:set (can_traverse rover0 way3 way4) false)
       	(:set (can_traverse rover0 way2 way4) false)
       	(:set (can_traverse rover0 way4 way0) false)
       	(:set (can_traverse rover0 way4 way3) false)
       	(:set (can_traverse rover0 way4 way2) false)

       	(:set (can_traverse rover0 way0 way5) false)
       	(:set (can_traverse rover0 way3 way5) false)
       	(:set (can_traverse rover0 way2 way5) false)
       	(:set (can_traverse rover0 way1 way5) false)
       	(:set (can_traverse rover0 way5 way0) false)
       	(:set (can_traverse rover0 way5 way3) false)
     	(:set (can_traverse rover0 way5 way2) false)
       	(:set (can_traverse rover0 way5 way1) false)
 
    (:set (can_traverse rover0 way3 way0) true)
        (:set (can_traverse rover0 way0 way3) true)
        (:set (can_traverse rover0 way3 way1) true)
        (:set (can_traverse rover0 way1 way3) true)
        (:set (can_traverse rover0 way1 way2) true)
        (:set (can_traverse rover0 way2 way1) true)
        (:set (can_traverse rover0 way1 way0) false)
        (:set (can_traverse rover0 way0 way1) false)
        (:set (can_traverse rover0 way2 way0) false)
        (:set (can_traverse rover0 way0 way2) false)
        (:set (can_traverse rover0 way2 way3) false)
        (:set (can_traverse rover0 way3 way2) false)
	(:set (have_image rover0 obj1 colour) false)
	(:set (have_image rover0 obj1 high_res) false)
	(:set (have_image rover0 obj1 low_res) false)
        (:set (on_board camera0 rover0) true)
        (:set (calibration_target camera0 obj1) true)
        (:set (supports camera0 colour) true)
        (:set (supports camera0 low_res) false)
        (:set (supports camera0 high_res) true)

	(:set (visible_from obj1) :in {way0 way4 way5})
;;	(:set (visible_from obj1) :in {way0})
	
	(:set (have_rock rover0) false)
	(:set (have_soil rover0) false)

	(:set (comm_img obj1 colour) false)
	(:set (comm_img obj1 low_res) false)
	(:set (comm_img obj1 high_res) false)
        (:set (have_image rover0 obj1 colour) false)
        (:set (have_image rover0 obj1 low_res) false)
        (:set (have_image rover0 obj1 high_res) false)
	(:set (comm_soil d) false)
	(:set (comm_rock d) false)



        (:set (calibrated camera0 rover0 way0 obj1) false) 
	(:set (calibrated camera0 rover0 way1 obj1) false) 
	(:set (calibrated camera0 rover0 way2 obj1) false) 
	(:set (calibrated camera0 rover0 way3 obj1) false) 
	(:set (calibrated camera0 rover0 way4 obj1) false)
 	(:set (calibrated camera0 rover0 way5 obj1) false)

)
(:goal (:and (comm_img obj1 high_res)
	(comm_soil d)
	(comm_rock d)
)))
