;;; This file contains some domains that exploit uncertainty:
;;;  - bt       is the classic bomb in the toilet domain with no sensing
;;;  - bct      makes the toilet clog if an empty package is dunked. 
;;;             flushing fixes the problem
;;;  - bcts     like bct, except allows multiple toilets
;;;  - bt-asym  demonstrates asymmetric subgoals (different subgoal structure
;;;             in different contexts). Also demonstrates confrontation

(in-package :domains)

(define (domain bt)
  (:requirements :strips :equality :typing :conditional-effects :uncertainty)
  (:action dunk
             :parameters (?p)
             :precondition (and (package ?p) (bomb ?b))           ; Need quant to put this in when
             :effect (when (in ?p ?b)
                       (defused ?b))))

(define (problem bt-dd)              ; graph-plan 1 steps, 2 actions
  (:domain bt)
  (:objects b p1 p2)
  (:init (package p1) (package p2) 
  	 (bomb b)
         (oneof (in p1 b) (in p2 b)))
  (:goal (defused b)))

(define (problem bt-dd2)             ; graph-plan 1 steps, 2 actions 
  (:domain bt)
  (:objects b p1 p2)
  (:init (package p1) (package p2) 
              (bomb b)
              (or (in p1 b) (in p2 b)))
  (:goal (defused b)))

(define (problem bt-dd3)              ; fails, can't defuse when bomb isn't there
  (:domain bt)
  (:objects b p1 p2)
  (:init (package p1) (package p2) 
         (bomb B)
         (uncertain (in p1 b) (in p2 b)))
  (:goal (defused b)))

(define (problem bt-ddd)              ; graph-plan 1 steps, 3 actions
  (:domain bt)
  (:objects b p1 p2 p3)
  (:init (package p1) (package p2) (package p3)
         (bomb b)
         (oneof (in p1 b) (in p2 b) (in p3 b)))
  (:goal (defused b)))
(define (problem bt-dd4)              ; graph-plan 1 steps, 3 actions
  (:domain bt)
  (:objects b p1 p2 p3 p4  )
  (:init (package p1) (package p2) (package p3)(package p4) 
         (bomb b)
         (oneof (in p1 b) (in p2 b) (in p3 b)(in p4 b) ))
  (:goal (defused b)))
(define (problem bt-dd6)              ; graph-plan 1 steps, 3 actions
  (:domain bt)
  (:objects b p1 p2 p3 p4 p5 p6 )
  (:init (package p1) (package p2) (package p3)(package p4) (package p5) (package p6)
         (bomb b)
         (oneof (in p1 b) (in p2 b) (in p3 b)(in p4 b) (in p5 b) (in p6 b) ))
  (:goal (defused b)))

(define (problem bt-dd8)              ; graph-plan 1 steps, 3 actions
  (:domain bt)
  (:objects b p1 p2 p3 p4 p5 p6 p7 p8)
  (:init (package p1) (package p2) (package p3)(package p4) (package p5) (package p6)(package p7) (package p8) 
         (bomb b)
         (oneof (in p1 b) (in p2 b) (in p3 b)(in p4 b) (in p5 b) (in p6 b)(in p7 b) (in p8 b) ))
  (:goal (defused b)))

(define (problem bt-dd10)              ; graph-plan 1 steps, 3 actions
  (:domain bt)
  (:objects b p1 p2 p3 p4 p5 p6 p7 p8 p9 p10)
  (:init (package p1) (package p2) (package p3)(package p4) (package p5) (package p6)(package p7) (package p8) (package p9)(package p10)
         (bomb b)
         (oneof (in p1 b) (in p2 b) (in p3 b)(in p4 b) (in p5 b) (in p6 b)(in p7 b) (in p8 b) (in p9 b)(in p10 b)))
  (:goal (defused b)))


(define (problem bt-dd20)              ; graph-plan 1 steps, 3 actions
  (:domain bt)
  (:objects b p1 p2 p3 p4 p5 p6 p7 p8 p9 p10 p11 p12 p13 p14 p15 p16 p17 p18 p19 p20 
)
  (:init (package p1) (package p2) (package p3)(package p4) (package p5) (package p6)(package p7) (package p8) (package p9)(package p10)(package p11) (package p12) (package p13)(package p14) (package p15) (package p16)(package p17) (package p18) (package p19)(package p20)
         (bomb b)
         (oneof (in p1 b) (in p2 b) (in p3 b)(in p4 b) (in p5 b) (in p6 b)(in p7 b) (in p8 b) (in p9 b)(in p10 b)(in p11 b) (in p12 b) (in p13 b)(in p14 b) (in p15 b) (in p16 b)(in p17 b) (in p18 b) (in p19 b)(in p20 b)
))
  (:goal (defused b)))

(define (problem bt-dd30)              ; graph-plan 1 steps, 3 actions
  (:domain bt)
  (:objects b p1 p2 p3 p4 p5 p6 p7 p8 p9 p10 p11 p12 p13 p14 p15 p16 p17 p18 p19 p20 p21 p22 p23 p24 p25 p26 p27 p28 p29 p30 
)
  (:init (package p1) (package p2) (package p3)(package p4) (package p5) (package p6)(package p7) (package p8) (package p9)(package p10)(package p11) (package p12) (package p13)(package p14) (package p15) (package p16)(package p17) (package p18) (package p19)(package p20)(package p21) (package p22) (package p23)(package p24) (package p25) (package p26)(package p27) (package p28) (package p29)(package p30)
         (bomb b)
         (oneof (in p1 b) (in p2 b) (in p3 b)(in p4 b) (in p5 b) (in p6 b)(in p7 b) (in p8 b) (in p9 b)(in p10 b)(in p11 b) (in p12 b) (in p13 b)(in p14 b) (in p15 b) (in p16 b)(in p17 b) (in p18 b) (in p19 b)(in p20 b)(in p21 b) (in p22 b) (in p23 b)(in p24 b) (in p25 b) (in p26 b)(in p27 b) (in p28 b) (in p29 b)(in p30 b)
))
  (:goal (defused b)))

(define (problem bt-dd40)              ; graph-plan 1 steps, 3 actions
  (:domain bt)
  (:objects b p1 p2 p3 p4 p5 p6 p7 p8 p9 p10 p11 p12 p13 p14 p15 p16 p17 p18 p19 p20 p21 p22 p23 p24 p25 p26 p27 p28 p29 p30 p31 p32 p33 p34 p35 p36 p37 p38 p39 p40 
)
  (:init (package p1) (package p2) (package p3)(package p4) (package p5) (package p6)(package p7) (package p8) (package p9)(package p10)(package p11) (package p12) (package p13)(package p14) (package p15) (package p16)(package p17) (package p18) (package p19)(package p20)(package p21) (package p22) (package p23)(package p24) (package p25) (package p26)(package p27) (package p28) (package p29)(package p30)(package p31) (package p32) (package p33)(package p34) (package p35) (package p36)(package p37) (package p38) (package p39)(package p40)
         (bomb b)
         (oneof (in p1 b) (in p2 b) (in p3 b)(in p4 b) (in p5 b) (in p6 b)(in p7 b) (in p8 b) (in p9 b)(in p10 b)(in p11 b) (in p12 b) (in p13 b)(in p14 b) (in p15 b) (in p16 b)(in p17 b) (in p18 b) (in p19 b)(in p20 b)(in p21 b) (in p22 b) (in p23 b)(in p24 b) (in p25 b) (in p26 b)(in p27 b) (in p28 b) (in p29 b)(in p30 b)(in p31 b) (in p32 b) (in p33 b)(in p34 b) (in p35 b) (in p36 b)(in p37 b) (in p38 b) (in p39 b)(in p40 b)
))
  (:goal (defused b)))

(define (problem bt-dd50)              ; graph-plan 1 steps, 3 actions
  (:domain bt)
  (:objects b p1 p2 p3 p4 p5 p6 p7 p8 p9 p10 p11 p12 p13 p14 p15 p16 p17 p18 p19 p20 p21 p22 p23 p24 p25 p26 p27 p28 p29 p30 p31 p32 p33 p34 p35 p36 p37 p38 p39 p40 p41 p42 p43 p44 p45 p46 p47 p48 p49 p50)
  (:init (package p1) (package p2) (package p3)(package p4) (package p5) (package p6)(package p7) (package p8) (package p9)(package p10)(package p11) (package p12) (package p13)(package p14) (package p15) (package p16)(package p17) (package p18) (package p19)(package p20)(package p21) (package p22) (package p23)(package p24) (package p25) (package p26)(package p27) (package p28) (package p29)(package p30)(package p31) (package p32) (package p33)(package p34) (package p35) (package p36)(package p37) (package p38) (package p39)(package p40)(package p41) (package p42) (package p43)(package p44) (package p45) (package p46)(package p47) (package p48) (package p49)(package p50)
         (bomb b)
         (oneof (in p1 b) (in p2 b) (in p3 b)(in p4 b) (in p5 b) (in p6 b)(in p7 b) (in p8 b) (in p9 b)(in p10 b)(in p11 b) (in p12 b) (in p13 b)(in p14 b) (in p15 b) (in p16 b)(in p17 b) (in p18 b) (in p19 b)(in p20 b)(in p21 b) (in p22 b) (in p23 b)(in p24 b) (in p25 b) (in p26 b)(in p27 b) (in p28 b) (in p29 b)(in p30 b)(in p31 b) (in p32 b) (in p33 b)(in p34 b) (in p35 b) (in p36 b)(in p37 b) (in p38 b) (in p39 b)(in p40 b)(in p41 b) (in p42 b) (in p43 b)(in p44 b) (in p45 b) (in p46 b)(in p47 b) (in p48 b) (in p49 b)(in p50 b)))
  (:goal (defused b)))

(define (problem bt-dd60)              ; graph-plan 1 steps, 3 actions
  (:domain bt)
  (:objects b p1 p2 p3 p4 p5 p6 p7 p8 p9 p10 p11 p12 p13 p14 p15 p16 p17 p18 p19 p20 p21 p22 p23 p24 p25 p26 p27 p28 p29 p30 p31 p32 p33 p34 p35 p36 p37 p38 p39 p40 p41 p42 p43 p44 p45 p46 p47 p48 p49 p50 p51 p52 p53 p54 p55 p56 p57 p58 p59 p60)
  (:init (package p1) (package p2) (package p3)(package p4) (package p5) (package p6)(package p7) (package p8) (package p9)(package p10)(package p11) (package p12) (package p13)(package p14) (package p15) (package p16)(package p17) (package p18) (package p19)(package p20)(package p21) (package p22) (package p23)(package p24) (package p25) (package p26)(package p27) (package p28) (package p29)(package p30)(package p31) (package p32) (package p33)(package p34) (package p35) (package p36)(package p37) (package p38) (package p39)(package p40)(package p41) (package p42) (package p43)(package p44) (package p45) (package p46)(package p47) (package p48) (package p49)(package p50)(package p51) (package p52) (package p53)(package p54) (package p55) (package p56)(package p57) (package p58) (package p59)(package p60)
         (bomb b)
         (oneof (in p1 b) (in p2 b) (in p3 b)(in p4 b) (in p5 b) (in p6 b)(in p7 b) (in p8 b) (in p9 b)(in p10 b)(in p11 b) (in p12 b) (in p13 b)(in p14 b) (in p15 b) (in p16 b)(in p17 b) (in p18 b) (in p19 b)(in p20 b)(in p21 b) (in p22 b) (in p23 b)(in p24 b) (in p25 b) (in p26 b)(in p27 b) (in p28 b) (in p29 b)(in p30 b)(in p31 b) (in p32 b) (in p33 b)(in p34 b) (in p35 b) (in p36 b)(in p37 b) (in p38 b) (in p39 b)(in p40 b)(in p41 b) (in p42 b) (in p43 b)(in p44 b) (in p45 b) (in p46 b)(in p47 b) (in p48 b) (in p49 b)(in p50 b)(in p51 b) (in p52 b) (in p53 b)(in p54 b) (in p55 b) (in p56 b)(in p57 b) (in p58 b) (in p59 b)(in p60 b)))
  (:goal (defused b)))

(define (problem bt-dd70)              ; graph-plan 1 steps, 3 actions
  (:domain bt)
  (:objects b p1 p2 p3 p4 p5 p6 p7 p8 p9 p10 p11 p12 p13 p14 p15 p16 p17 p18 p19 p20 p21 p22 p23 p24 p25 p26 p27 p28 p29 p30 p31 p32 p33 p34 p35 p36 p37 p38 p39 p40 p41 p42 p43 p44 p45 p46 p47 p48 p49 p50 p51 p52 p53 p54 p55 p56 p57 p58 p59 p60 p61 p62 p63 p64 p65 p66 p67 p68 p69 p70 )
  (:init (package p1) (package p2) (package p3)(package p4) (package p5) (package p6)(package p7) (package p8) (package p9)(package p10)(package p11) (package p12) (package p13)(package p14) (package p15) (package p16)(package p17) (package p18) (package p19)(package p20)(package p21) (package p22) (package p23)(package p24) (package p25) (package p26)(package p27) (package p28) (package p29)(package p30)(package p31) (package p32) (package p33)(package p34) (package p35) (package p36)(package p37) (package p38) (package p39)(package p40)(package p41) (package p42) (package p43)(package p44) (package p45) (package p46)(package p47) (package p48) (package p49)(package p50) (package p51) (package p52) (package p53)(package p54) (package p55) (package p56)(package p57) (package p58) (package p59) (package p60) (package p61) (package p62) (package p63)(package p64) (package p65) (package p66)(package p67) (package p68) (package p69)(package p70)
         (bomb b)
         (oneof (in p1 b) (in p2 b) (in p3 b)(in p4 b) (in p5 b) (in p6 b)(in p7 b) (in p8 b) (in p9 b)(in p10 b)(in p11 b) (in p12 b) (in p13 b)(in p14 b) (in p15 b) (in p16 b)(in p17 b) (in p18 b) (in p19 b)(in p20 b)(in p21 b) (in p22 b) (in p23 b)(in p24 b) (in p25 b) (in p26 b)(in p27 b) (in p28 b) (in p29 b)(in p30 b)(in p31 b) (in p32 b) (in p33 b)(in p34 b) (in p35 b) (in p36 b)(in p37 b) (in p38 b) (in p39 b)(in p40 b)(in p41 b) (in p42 b) (in p43 b)(in p44 b) (in p45 b) (in p46 b)(in p47 b) (in p48 b) (in p49 b)(in p50 b)(in p51 b) (in p52 b) (in p53 b)(in p54 b) (in p55 b) (in p56 b)(in p57 b) (in p58 b) (in p59 b)(in p60 b)(in p61 b) (in p62 b) (in p63 b)(in p64 b) (in p65 b) (in p66 b)(in p67 b) (in p68 b) (in p69 b)(in p70 b)))
  (:goal (defused b)))

(define (problem bt-dd80)              ; graph-plan 1 steps, 3 actions
  (:domain bt)
  (:objects b p1 p2 p3 p4 p5 p6 p7 p8 p9 p10 p11 p12 p13 p14 p15 p16 p17 p18 p19 p20 p21 p22 p23 p24 p25 p26 p27 p28 p29 p30 p31 p32 p33 p34 p35 p36 p37 p38 p39 p40 p41 p42 p43 p44 p45 p46 p47 p48 p49 p50 p51 p52 p53 p54 p55 p56 p57 p58 p59 p60 p61 p62 p63 p64 p65 p66 p67 p68 p69 p70 p71 p72 p73 p74 p75 p76 p77 p78 p79 p80 )
  (:init (package p1) (package p2) (package p3)(package p4) (package p5) (package p6)(package p7) (package p8) (package p9)(package p10)(package p11) (package p12) (package p13)(package p14) (package p15) (package p16)(package p17) (package p18) (package p19)(package p20)(package p21) (package p22) (package p23)(package p24) (package p25) (package p26)(package p27) (package p28) (package p29)(package p30)(package p31) (package p32) (package p33)(package p34) (package p35) (package p36)(package p37) (package p38) (package p39)(package p40)(package p41) (package p42) (package p43)(package p44) (package p45) (package p46)(package p47) (package p48) (package p49)(package p50) (package p51) (package p52) (package p53)(package p54) (package p55) (package p56)(package p57) (package p58) (package p59) (package p60) (package p61) (package p62) (package p63)(package p64) (package p65) (package p66)(package p67) (package p68) (package p69)(package p70)(package p71) (package p72) (package p73)(package p74) (package p75) (package p76)(package p77) (package p78) (package p79)(package p80)
         (bomb b)
         (oneof (in p1 b) (in p2 b) (in p3 b)(in p4 b) (in p5 b) (in p6 b)(in p7 b) (in p8 b) (in p9 b)(in p10 b)(in p11 b) (in p12 b) (in p13 b)(in p14 b) (in p15 b) (in p16 b)(in p17 b) (in p18 b) (in p19 b)(in p20 b)(in p21 b) (in p22 b) (in p23 b)(in p24 b) (in p25 b) (in p26 b)(in p27 b) (in p28 b) (in p29 b)(in p30 b)(in p31 b) (in p32 b) (in p33 b)(in p34 b) (in p35 b) (in p36 b)(in p37 b) (in p38 b) (in p39 b)(in p40 b)(in p41 b) (in p42 b) (in p43 b)(in p44 b) (in p45 b) (in p46 b)(in p47 b) (in p48 b) (in p49 b)(in p50 b)(in p51 b) (in p52 b) (in p53 b)(in p54 b) (in p55 b) (in p56 b)(in p57 b) (in p58 b) (in p59 b)(in p60 b)(in p61 b) (in p62 b) (in p63 b)(in p64 b) (in p65 b) (in p66 b)(in p67 b) (in p68 b) (in p69 b)(in p70 b)(in p71 b) (in p72 b) (in p73 b)(in p74 b) (in p75 b) (in p76 b)(in p77 b) (in p78 b) (in p79 b)(in p80 b)))
  (:goal (defused b)))


(define (problem bt-dd100)              ; graph-plan 1 steps, 3 actions
  (:domain bt)
  (:objects b p1 p2 p3 p4 p5 p6 p7 p8 p9 p10 p11 p12 p13 p14 p15 p16 p17 p18 p19 p20 p21 p22 p23 p24 p25 p26 p27 p28 p29 p30 p31 p32 p33 p34 p35 p36 p37 p38 p39 p40 p41 p42 p43 p44 p45 p46 p47 p48 p49 p50 p51 p52 p53 p54 p55 p56 p57 p58 p59 p60 p61 p62 p63 p64 p65 p66 p67 p68 p69 p70 p71 p72 p73 p74 p75 p76 p77 p78 p79 p80 p81 p82 p83 p84 p85 p86 p87 p88 p89 p90 p91 p92 p93 p94 p95 p96 p97 p98 p99 p100)
  (:init (package p1) (package p2) (package p3)(package p4) (package p5) (package p6)(package p7) (package p8) (package p9)(package p10)(package p11) (package p12) (package p13)(package p14) (package p15) (package p16)(package p17) (package p18) (package p19)(package p20)(package p21) (package p22) (package p23)(package p24) (package p25) (package p26)(package p27) (package p28) (package p29)(package p30)(package p31) (package p32) (package p33)(package p34) (package p35) (package p36)(package p37) (package p38) (package p39)(package p40)(package p41) (package p42) (package p43)(package p44) (package p45) (package p46)(package p47) (package p48) (package p49)(package p50) (package p51) (package p52) (package p53)(package p54) (package p55) (package p56)(package p57) (package p58) (package p59) (package p60) (package p61) (package p62) (package p63)(package p64) (package p65) (package p66)(package p67) (package p68) (package p69)(package p70)(package p71) (package p72) (package p73)(package p74) (package p75) (package p76)(package p77) (package p78) (package p79)(package p80)(package p81) (package p82) (package p83)(package p84) (package p85) (package p86)(package p87) (package p88) (package p89)(package p90) (package p91) (package p92) (package p93)(package p94) (package p95) (package p96)(package p97) (package p98) (package p99)(package p100)
         (bomb b)
         (oneof (in p1 b) (in p2 b) (in p3 b)(in p4 b) (in p5 b) (in p6 b)(in p7 b) (in p8 b) (in p9 b)(in p10 b)(in p11 b) (in p12 b) (in p13 b)(in p14 b) (in p15 b) (in p16 b)(in p17 b) (in p18 b) (in p19 b)(in p20 b)(in p21 b) (in p22 b) (in p23 b)(in p24 b) (in p25 b) (in p26 b)(in p27 b) (in p28 b) (in p29 b)(in p30 b)(in p31 b) (in p32 b) (in p33 b)(in p34 b) (in p35 b) (in p36 b)(in p37 b) (in p38 b) (in p39 b)(in p40 b)(in p41 b) (in p42 b) (in p43 b)(in p44 b) (in p45 b) (in p46 b)(in p47 b) (in p48 b) (in p49 b)(in p50 b)(in p51 b) (in p52 b) (in p53 b)(in p54 b) (in p55 b) (in p56 b)(in p57 b) (in p58 b) (in p59 b)(in p60 b)(in p61 b) (in p62 b) (in p63 b)(in p64 b) (in p65 b) (in p66 b)(in p67 b) (in p68 b) (in p69 b)(in p70 b)(in p71 b) (in p72 b) (in p73 b)(in p74 b) (in p75 b) (in p76 b)(in p77 b) (in p78 b) (in p79 b)(in p80 b)(in p81 b) (in p82 b) (in p83 b)(in p84 b) (in p85 b) (in p86 b)(in p87 b) (in p88 b) (in p89 b)(in p90 b)(in p91 b) (in p92 b) (in p93 b)(in p94 b) (in p95 b) (in p96 b)(in p97 b) (in p98 b) (in p99 b)(in p100 b)))
  (:goal (defused b)))

(define (domain bct)
  (:requirements :strips :equality :typing :conditional-effects :uncertainty)
  (:action dunk
             :parameters (?p)
             :precondition (and (package ?p) (bomb ?b) (not (clogged))) ; Need quant to put this in when
             :effect (and (clogged)
		           (when (in ?p ?b)
		             (defused ?b))))
  (:action flush
             :parameters ()
             :precondition (clogged)
             :effect (not (clogged))))

(define (problem bct-df1)              
  (:domain bct)
  (:objects b p1)
  (:init (package p1)
         (bomb B) (not (clogged))
         (in p1 b))
  (:goal (defused b)))

(define (problem bct-df2)              
  (:domain bct)
  (:objects b p1 p2)
  (:init (package p1) (package p2)
         (bomb B) (not (clogged))
         (oneof (in p1 b) (in p2 b)))
  (:goal (defused b)))

(define (problem bct-df3)              
  (:domain bct)
  (:objects b p1 p2 p3)
  (:init (package p1) (package p2) (package p3)
         (bomb B) (not (clogged))
         (oneof (in p1 b) (in p2 b) (in p3 b)))
  (:goal (defused b)))

(define (problem bct-df4)              
  (:domain bct)
  (:objects b p1 p2 p3 p4)
  (:init (package p1) (package p2) (package p3) (package p4)
         (bomb B) (not (clogged))
         (oneof (in p1 b) (in p2 b) (in p3 b) (in p4 b)))
  (:goal (defused b)))

(define (problem bct-df5)              ; five dunks; four flushes
  (:domain bct)
  (:objects b p1 p2 p3 p4 p5)
  (:init (package p1) (package p2) (package p3) (package p4) (package p5)
         (bomb B) (not (clogged))
         (oneof (in p1 b) (in p2 b) (in p3 b) (in p4 b) (in p5 b)))
  (:goal (defused b)))

(define (problem bct-df6)              ; five dunks; four flushes
  (:domain bct)
  (:objects b p1 p2 p3 p4 p5 p6)
  (:init (package p1) (package p2) (package p3) (package p4) (package p5) (package p6)
         (bomb B) (not (clogged))
         (oneof (in p1 b) (in p2 b) (in p3 b) (in p4 b) (in p5 b) (in p6 b)))
  (:goal (defused b)))

(define (problem bct-df7)              ; five dunks; four flushes
  (:domain bct)
  (:objects b p1 p2 p3 p4 p5 p6 p7)
  (:init (package p1) (package p2) (package p3) (package p4) (package p5) (package p6) (package p7)
         (bomb B) (not (clogged))
         (oneof (in p1 b) (in p2 b) (in p3 b) (in p4 b) (in p5 b) (in p6 b) (in p7 b)))
  (:goal (defused b)))

(define (problem bct-df8)
  (:domain bct)
  (:objects b p1 p2 p3 p4 p5 p6 p7 p8 )
  (:init (package p1) (package p2) (package p3) (package p4) (package p5) (package p6) (package p7)(package p8) 
         (bomb B) (not (clogged))
         (oneof (in p1 b) (in p2 b) (in p3 b) (in p4 b) (in p5 b) (in p6 b) (in p7 b)(in p8 b)))
  (:goal (defused b)))

(define (problem bct-df10)
  (:domain bct)
  (:objects b p1 p2 p3 p4 p5 p6 p7 p8 p9 p10)
  (:init (package p1) (package p2) (package p3) (package p4) (package p5) (package p6) (package p7)(package p8) (package p9) (package p10)
         (bomb B) (not (clogged))
         (oneof (in p1 b) (in p2 b) (in p3 b) (in p4 b) (in p5 b) (in p6 b) (in p7 b)(in p8 b) (in p9 b) (in p10 b)))
  (:goal (defused b)))

(define (problem bct-df15)
  (:domain bct)
  (:objects b p1 p2 p3 p4 p5 p6 p7 p8 p9 p10 p11 p12 p13 p14 p15)
  (:init (package p1) (package p2) (package p3) (package p4) (package p5) (package p6) (package p7)(package p8) (package p9) (package p10)(package p11) (package p12) (package p13) (package p14) (package p15)
         (bomb B) (not (clogged))
         (oneof (in p1 b) (in p2 b) (in p3 b) (in p4 b) (in p5 b) (in p6 b) (in p7 b)(in p8 b) (in p9 b) (in p10 b)(in p11 b) (in p12 b) (in p13 b) (in p14 b) (in p15 b)))
  (:goal (defused b)))

(define (problem bct-df20)
  (:domain bct)
  (:objects b p1 p2 p3 p4 p5 p6 p7 p8 p9 p10 p11 p12 p13 p14 p15 p16 p17 p18 p19 p20)
  (:init (package p1) (package p2) (package p3) (package p4) (package p5) (package p6) (package p7)(package p8) (package p9) (package p10)(package p11) (package p12) (package p13) (package p14) (package p15)(package p16) (package p17)(package p18) (package p19) (package p20)
         (bomb B) (not (clogged))
         (oneof (in p1 b) (in p2 b) (in p3 b) (in p4 b) (in p5 b) (in p6 b) (in p7 b)(in p8 b) (in p9 b) (in p10 b)(in p11 b) (in p12 b) (in p13 b) (in p14 b) (in p15 b)(in p16 b) (in p17 b)(in p18 b) (in p19 b) (in p20 b)))
  (:goal (defused b)))

(define (problem bct-df30)
  (:domain bct)
  (:objects b p1 p2 p3 p4 p5 p6 p7 p8 p9 p10 p11 p12 p13 p14 p15 p16 p17 p18 p19 p20 p21 p22 p23 p24 p25 p26 p27 p28 p29 p30)
  (:init (package p1) (package p2) (package p3) (package p4) (package p5) (package p6) (package p7)(package p8) (package p9) (package p10)(package p11) (package p12) (package p13) (package p14) (package p15)(package p16) (package p17)(package p18) (package p19) (package p20)(package p21) (package p22) (package p23) (package p24) (package p25)(package p26) (package p27)(package p28) (package p29) (package p30)
         (bomb B) (not (clogged))
         (oneof (in p1 b) (in p2 b) (in p3 b) (in p4 b) (in p5 b) (in p6 b) (in p7 b)(in p8 b) (in p9 b) (in p10 b)(in p11 b) (in p12 b) (in p13 b) (in p14 b) (in p15 b)(in p16 b) (in p17 b)(in p18 b) (in p19 b) (in p20 b)(in p21 b) (in p22 b) (in p23 b) (in p24 b) (in p25 b)(in p26 b) (in p27 b)(in p28 b) (in p29 b) (in p30 b)))
  (:goal (defused b)))

(define (problem bct-df50)
  (:domain bct)
  (:objects b p1 p2 p3 p4 p5 p6 p7 p8 p9 p10 p11 p12 p13 p14 p15 p16 p17 p18 p19 p20 p21 p22 p23 p24 p25 p26 p27 p28 p29 p30 p31 p32 p33 p34 p35 p36 p37 p38 p39 p40 p41 p42 p43 p44 p45 p46 p47 p48 p49 p50)
  (:init (package p1) (package p2) (package p3) (package p4) (package p5) (package p6) (package p7)(package p8) (package p9) (package p10)(package p11) (package p12) (package p13) (package p14) (package p15)(package p16) (package p17)(package p18) (package p19) (package p20)(package p21) (package p22) (package p23) (package p24) (package p25)(package p26) (package p27)(package p28) (package p29) (package p30)(package p31) (package p32) (package p33) (package p34) (package p35)(package p36) (package p37)(package p38) (package p39) (package p40)(package p41) (package p42) (package p43) (package p44) (package p45)(package p46) (package p47)(package p48) (package p49) (package p50)
         (bomb B) (not (clogged))
         (oneof (in p1 b) (in p2 b) (in p3 b) (in p4 b) (in p5 b) (in p6 b) (in p7 b)(in p8 b) (in p9 b) (in p10 b)(in p11 b) (in p12 b) (in p13 b) (in p14 b) (in p15 b)(in p16 b) (in p17 b)(in p18 b) (in p19 b) (in p20 b)(in p21 b) (in p22 b) (in p23 b) (in p24 b) (in p25 b)(in p26 b) (in p27 b)(in p28 b) (in p29 b) (in p30 b)(in p31 b) (in p32 b) (in p33 b) (in p34 b) (in p35 b)(in p36 b) (in p37 b)(in p38 b) (in p39 b) (in p40 b)(in p41 b) (in p42 b) (in p43 b) (in p44 b) (in p45 b)(in p46 b) (in p47 b)(in p48 b) (in p49 b) (in p50 b)))
  (:goal (defused b)))
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Like previous version except allows for multiple toilets
;;;

(define (domain bcts)
  (:requirements :strips :equality :typing :conditional-effects :uncertainty)
  (:action dunk
             :parameters (?p ?t)
             :precondition (and (toilet ?t) (package ?p) 
                                (bomb ?b) (not (clogged ?t))) ; Need quant to put this in when
             :effect (and (clogged ?t)
		           (when (in ?p ?b)
		             (defused ?b))))
  (:action flush
             :parameters (?t)
             :precondition (and (toilet ?t) (clogged ?t))
             :effect (not (clogged ?t))))

;;;;;;;;;;;;;;;;;;;;
;;; Single toilet

(define (problem bcts-t1p1)              
  (:domain bcts)
  (:objects b t1 p1)
  (:init (bomb B)
         (package p1)
         (toilet t1) (not (clogged t1))
         (in p1 b))
  (:goal (defused b)))

(define (problem bcts-t1p2)              
  (:domain bcts)
  (:objects b t1 p1 p2)
  (:init (bomb B)
         (package p1) (package p2)
         (toilet t1) (not (clogged t1))
         (oneof (in p1 b) (in p2 b)))
  (:goal (defused b)))

(define (problem bcts-t1p3)              
  (:domain bcts)
  (:objects b t1 p1 p2 p3)
  (:init (bomb B)
         (package p1) (package p2) (package p3)
         (toilet t1) (not (clogged t1))
         (oneof (in p1 b) (in p2 b) (in p3 b)))
  (:goal (defused b)))

(define (problem bcts-t1p4)              
  (:domain bcts)
  (:objects b t1 p1 p2 p3 p4)
  (:init (bomb B)
         (package p1) (package p2) (package p3) (package p4)
         (toilet t1) (not (clogged t1))
         (oneof (in p1 b) (in p2 b) (in p3 b) (in p4 b)))
  (:goal (defused b)))

(define (problem bcts-t1p5)              ; five dunks; four flushes
  (:domain bcts)
  (:objects b t1 p1 p2 p3 p4 p5)
  (:init (bomb B)
         (package p1) (package p2) (package p3) (package p4) (package p5)
         (toilet t1) (not (clogged t1))
         (oneof (in p1 b) (in p2 b) (in p3 b) (in p4 b) (in p5 b)))
  (:goal (defused b)))

(define (problem bcts-t1p6)              ; five dunks; four flushes
  (:domain bcts)
  (:objects b t1 p1 p2 p3 p4 p5 p6)
  (:init (bomb B)
         (package p1) (package p2) (package p3) (package p4) (package p5) (package p6)
         (toilet t1) (not (clogged t1))
         (oneof (in p1 b) (in p2 b) (in p3 b) (in p4 b) (in p5 b) (in p6 b)))
  (:goal (defused b)))

(define (problem bcts-t1p7)              ; five dunks; four flushes
  (:domain bcts)
  (:objects b t1 p1 p2 p3 p4 p5 p6 p7)
  (:init (bomb B)
         (package p1) (package p2) (package p3) (package p4) (package p5) (package p6) (package p7)
         (toilet t1) (not (clogged t1))
         (oneof (in p1 b) (in p2 b) (in p3 b) (in p4 b) (in p5 b) (in p6 b) (in p7 b)))
  (:goal (defused b)))

;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Two toilets

(define (problem bcts-t2p2)              
  (:domain bcts)
  (:objects b t1 t2 p1 p2)
  (:init (package p1) (package p2) (bomb B)
         (toilet t1) (not (clogged t1)) (toilet t2) (not (clogged t2))
         (oneof (in p1 b) (in p2 b)))
  (:goal (defused b)))

(define (problem bcts-t2p3)              
  (:domain bcts)
  (:objects b t1 t2 p1 p2 p3)
  (:init (package p1) (package p2) (package p3) (bomb B)
         (toilet t1) (not (clogged t1)) (toilet t2) (not (clogged t2))
         (oneof (in p1 b) (in p2 b) (in p3 b)))
  (:goal (defused b)))

(define (problem bcts-t2p4)              
  (:domain bcts)
  (:objects b t1 t2 p1 p2 p3 p4)
  (:init (package p1) (package p2) (package p3) (package p4) (bomb B)
         (toilet t1) (not (clogged t1)) (toilet t2) (not (clogged t2))
         (oneof (in p1 b) (in p2 b) (in p3 b) (in p4 b)))
  (:goal (defused b)))


(define (problem bcts-t2p5)              ; five dunks; four flushes
  (:domain bcts)
  (:objects b t1 t2 p1 p2 p3 p4 p5)
  (:init (package p1) (package p2) (package p3) (package p4) (package p5) (bomb B)
         (toilet t1) (not (clogged t1)) (toilet t2) (not (clogged t2))
         (oneof (in p1 b) (in p2 b) (in p3 b) (in p4 b) (in p5 b)))
  (:goal (defused b)))

(define (problem bcts-t2p6)              ; five dunks; four flushes
  (:domain bcts)
  (:objects b t1 t2 p1 p2 p3 p4 p5 p6)
  (:init (bomb B)
         (package p1) (package p2) (package p3) (package p4) (package p5) (package p6)
         (toilet t1) (not (clogged t1)) (toilet t2) (not (clogged t2))
         (oneof (in p1 b) (in p2 b) (in p3 b) (in p4 b) (in p5 b) (in p6 b)))
  (:goal (defused b)))

(define (problem bcts-t2p7)              ; five dunks; four flushes
  (:domain bcts)
  (:objects b t1 t2 p1 p2 p3 p4 p5 p6 p7)
  (:init (bomb B)
         (package p1) (package p2) (package p3) (package p4) (package p5) (package p6) (package p7)
         (toilet t1) (not (clogged t1)) (toilet t2) (not (clogged t2))
         (oneof (in p1 b) (in p2 b) (in p3 b) (in p4 b) (in p5 b) (in p6 b) (in p7 b)))
  (:goal (defused b)))

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;; Three toilets

(define (problem bcts-t3p2)              ; five dunks; four flushes
  (:domain bcts)
  (:objects b t1 t2 t3 p1 p2)
  (:init (bomb B)
         (package p1) (package p2)
         (toilet t1) (not (clogged t1)) (toilet t2) (not (clogged t2)) (toilet t3) (not (clogged t3))
         (oneof (in p1 b) (in p2 b)))
  (:goal (defused b)))

(define (problem bcts-t3p3)              ; five dunks; four flushes
  (:domain bcts)
  (:objects b t1 t2 t3 p1 p2 p3)
  (:init (bomb B)
         (package p1) (package p2) (package p3)
         (toilet t1) (not (clogged t1)) (toilet t2) (not (clogged t2)) (toilet t3) (not (clogged t3))
         (oneof (in p1 b) (in p2 b) (in p3 b)))
  (:goal (defused b)))

(define (problem bcts-t3p4)              ; five dunks; four flushes
  (:domain bcts)
  (:objects b t1 t2 t3 p1 p2 p3 p4)
  (:init (bomb B)
         (package p1) (package p2) (package p3) (package p4)
         (toilet t1) (not (clogged t1)) (toilet t2) (not (clogged t2)) (toilet t3) (not (clogged t3))
         (oneof (in p1 b) (in p2 b) (in p3 b) (in p4 b)))
  (:goal (defused b)))

(define (problem bcts-t3p5)              ; five dunks; four flushes
  (:domain bcts)
  (:objects b t1 t2 t3 p1 p2 p3 p4 p5)
  (:init (bomb B)
         (package p1) (package p2) (package p3) (package p4) (package p5)
         (toilet t1) (not (clogged t1)) (toilet t2) (not (clogged t2)) (toilet t3) (not (clogged t3))
         (oneof (in p1 b) (in p2 b) (in p3 b) (in p4 b) (in p5 b)))
  (:goal (defused b)))

(define (problem bcts-t3p6)              ; five dunks; four flushes
  (:domain bcts)
  (:objects b t1 t2 t3 p1 p2 p3 p4 p5 p6)
  (:init (bomb B)
         (package p1) (package p2) (package p3) (package p4) (package p5) (package p6)
         (toilet t1) (not (clogged t1)) (toilet t2) (not (clogged t2)) (toilet t3) (not (clogged t3))
         (oneof (in p1 b) (in p2 b) (in p3 b) (in p4 b) (in p5 b) (in p6 b)))
  (:goal (defused b)))


;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(define (domain bt-asym)
  (:requirements :strips :equality  :typing :conditional-effects :uncertainty)
  (:action dunka
             :parameters ()
             :precondition (and (enabled) (not (clogged))) 
             :effect (when (bomb-in-a) 
                       (defused)))
  (:action dunkb
             :parameters ()
             :precondition (enabled)
             :effect (and (when (bomb-in-b)
		             (defused))
		           (when (and (not (bomb-in-b)) (not (pumping)))
		             (clogged))))
  (:action enable
             :parameters ()
             :precondition ()
             :effect (enabled))
  (:action pump
             :parameters ()
             :precondition ()
             :effect (pumping)))

(define (problem bta-c)
  (:domain bt-asym)
  (:objects )
  (:init (not (clogged)) (not (enabled)) (not (pumping))
         (oneof (bomb-in-a) (bomb-in-b)))
  (:goal (defused)))

